To help us diagnose issues efficiently, please include:

- A short but descriptive title
- A detailed description of the problem including relevant software versions and steps to reproduce
- A fix or workaround if you know it
